var arrayConcat = require('../internal/arrayConcat'),
    baseFlatten = require('../internal/baseFlatten'),
    isArray = require('../lang/isArray'),
    restParam = require('../function/restParam'),
    toObject = require('../internal/toObject');

/*  Gets the value at `key`, unless `key` is "__proto__" or "constructor".
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */
function safeGet(object, key) {
  if (key === 'constructor' && typeof object[key] === 'function') {
    return;
  }

  if (key == '__proto__') {
    return;
  }
  return object[key];
}

/**
 * Creates a new array joining a wrapped array with any additional arrays
 * and/or values.
 *
 * @name concat
 * @memberOf _
 * @category Chain
 * @param {...*} [values] The values to concatenate.
 * @returns {Array} Returns the new concatenated array.
 * @example
 *
 * var array = [1];
 * var wrapped = _(array).concat(2, [3], [[4]]);
 *
 * console.log(wrapped.value());
 * // => [1, 2, 3, [4]]
 *
 * console.log(array);
 * // => [1]
 */
var wrapperConcat = restParam(function(values) {
  values = baseFlatten(values);
  return this.thru(function(array) {
    return arrayConcat(isArray(array) ? array : [toObject(array)], values);
  });
});

module.exports = wrapperConcat;
